@@ -6,14 +6,12 @@
 # https://gitlab.com/tsfpga/tsfpga
 # --------------------------------------------------------------------------------------------------
 
-"""
-A set of reusable functions for working with HDL projects.
-"""
-
-
 # Standard libraries
 from pathlib import Path
 
+# Local folder libraries
+from .about import get_pypi_slogan
+
 THIS_DIR = Path(__file__).parent
 REPO_ROOT = THIS_DIR.parent.resolve()
 
@@ -28,4 +26,5 @@ TSFPGA_EXAMPLE_MODULES = TSFPGA_EXAMPLES / "modules"
 # Default encoding when opening files
 DEFAULT_FILE_ENCODING = "utf-8"
 
-__version__ = "12.0.1"
+__version__ = "12.0.2"
+__doc__ = get_pypi_slogan()  # pylint: disable=redefined-builtin
