@@ -1,7 +1,7 @@
 # --------------------------------------------------------------------------------------------------
 # Copyright (c) Lukas Vik. All rights reserved.
 #
-# This file is part of the tsfpga project.
+# This file is part of the tsfpga project, a project platform for modern FPGA development.
 # https://tsfpga.com
 # https://gitlab.com/tsfpga/tsfpga
 # --------------------------------------------------------------------------------------------------
@@ -10,19 +10,14 @@
 Common functions and definitions in the example build environment.
 """
 
-import sys
+# Import before others since it modifies PYTHONPATH. pylint: disable=unused-import
+import tsfpga.examples.example_pythonpath  # noqa: F401
 
-import tsfpga
-
-# Do PYTHONPATH insert() instead of append() to prefer any local repo checkout over any pip install
-PATH_TO_HDL_REGISTERS = tsfpga.REPO_ROOT.parent.resolve() / "hdl_registers"
-sys.path.insert(0, str(PATH_TO_HDL_REGISTERS))
-PATH_TO_VUNIT = tsfpga.REPO_ROOT.parent.parent.resolve() / "vunit" / "vunit"
-sys.path.insert(0, str(PATH_TO_VUNIT))
-
-# pylint: disable=wrong-import-order
+# Third party libraries
 from hdl_registers.register_list import Register
 
+# First party libraries
+import tsfpga
 from tsfpga.module import get_modules
 
 TSFPGA_EXAMPLES_TEMP_DIR = tsfpga.TSFPGA_GENERATED
@@ -75,3 +70,30 @@ def get_tsfpga_example_modules(names_include=None, names_avoid=None):
         library_name_has_lib_suffix=False,
         default_registers=get_default_registers(),
     )
+
+
+def get_hdl_modules(names_include=None, names_avoid=None):
+    """
+    Wrapper of :func:`.get_modules` which returns the ``hdl_modules`` module objects.
+
+    If ``hdl_modules`` can not be found in the default repo checkout location,
+    the function will assert False.
+
+    Arguments will be passed on to :func:`.get_modules`.
+
+    Return:
+        :class:`.ModuleList`: The module objects.
+    """
+    # Presumed location of the hdl_modules repo
+    hdl_modules_repo_root = tsfpga.REPO_ROOT.parent.parent.resolve() / "hdl_modules" / "hdl_modules"
+    if (hdl_modules_repo_root / "modules").exists():
+        return get_modules(
+            modules_folders=[hdl_modules_repo_root / "modules"],
+            names_include=names_include,
+            names_avoid=names_avoid,
+            library_name_has_lib_suffix=False,
+        )
+
+    raise FileNotFoundError(
+        f"The hdl_modules modules could not be found. Searched in {hdl_modules_repo_root}"
+    )
