@@ -1,23 +1,27 @@
 # --------------------------------------------------------------------------------------------------
 # Copyright (c) Lukas Vik. All rights reserved.
 #
-# This file is part of the tsfpga project.
+# This file is part of the tsfpga project, a project platform for modern FPGA development.
 # https://tsfpga.com
 # https://gitlab.com/tsfpga/tsfpga
 # --------------------------------------------------------------------------------------------------
 
+# Standard libraries
 import unittest
-from unittest.mock import MagicMock, patch
 from pathlib import Path
+from unittest.mock import MagicMock, patch
 
+# Third party libraries
 import pytest
 
+# First party libraries
 from tsfpga.module import BaseModule
 from tsfpga.system_utils import create_directory, create_file
-from tsfpga.vivado.project import VivadoProject, copy_and_combine_dicts
 
 # pylint: disable=unused-import
 from tsfpga.test.conftest import fixture_tmp_path  # noqa: F401
+from tsfpga.vivado.generics import StringGenericValue
+from tsfpga.vivado.project import VivadoNetlistProject, VivadoProject, copy_and_combine_dicts
 
 
 def test_casting_to_string():
@@ -33,7 +37,11 @@ Generics:   -
     )
 
     project = VivadoProject(
-        name="my_project", modules=[], part="", top="apa", generics=dict(hest=2, zebra=3)
+        name="my_project",
+        modules=[],
+        part="",
+        top="apa",
+        generics=dict(hest=True, zebra=3, foo=StringGenericValue("/home/test.vhd")),
     )
     assert (
         str(project)
@@ -41,7 +49,7 @@ Generics:   -
 my_project
 Type:       VivadoProject
 Top level:  apa
-Generics:   hest=2, zebra=3
+Generics:   hest=True, zebra=3, foo=/home/test.vhd
 """
     )
 
@@ -67,11 +75,11 @@ def test_modules_list_should_be_copied():
 
 
 def test_static_generics_dictionary_should_be_copied():
-    generics = dict(apa=1)
+    generics = dict(apa=3)
     proj = VivadoProject(name="name", modules=[], part="part", generics=generics)
 
-    generics["apa"] = 2
-    assert proj.static_generics["apa"] == 1
+    generics["apa"] = False
+    assert proj.static_generics["apa"] == 3
 
 
 def test_constraints_list_should_be_copied():
@@ -131,19 +139,6 @@ def test_project_create_should_raise_exception_if_project_path_already_exists(tm
     assert str(exception_info.value) == f"Folder already exists: {project_path}"
 
 
-def test_can_cast_project_to_string_without_error():
-    print(VivadoProject(name="name", modules=[], part=""))
-    print(
-        VivadoProject(
-            name="name",
-            modules=[],
-            part="",
-            generics=dict(stuff="and", things=True),
-            defined_at=Path(__file__),
-        )
-    )
-
-
 def test_copy_and_combine_dict_with_both_arguments_none():
     assert copy_and_combine_dicts(None, None) is None
 
@@ -201,17 +196,17 @@ def test_copy_and_combine_dict_with_both_arguments_valid_and_same_key():
 # pylint: disable=too-many-instance-attributes
 @pytest.mark.usefixtures("fixture_tmp_path")
 class TestVivadoProject(unittest.TestCase):
-
     tmp_path = None
 
     def setUp(self):
         self.project_path = self.tmp_path / "projects" / "apa" / "project"
         self.output_path = self.tmp_path / "projects" / "apa"
         self.ip_cache_path = MagicMock()
-        self.build_time_generics = dict(name="value")
+        self.build_time_generics = dict(enable=True)
         self.num_threads = 4
         self.run_index = 3
         self.synth_only = False
+        self.from_impl = False
 
         self.mocked_run_vivado_tcl = None
 
@@ -225,7 +220,6 @@ class TestVivadoProject(unittest.TestCase):
 
     def test_default_pre_create_hook_should_pass(self):
         class CustomVivadoProject(VivadoProject):
-
             pass
 
         project = CustomVivadoProject(name="apa", modules=[], part="")
@@ -234,7 +228,7 @@ class TestVivadoProject(unittest.TestCase):
 
     def test_project_pre_create_hook_returning_false_should_fail_and_not_call_vivado_run(self):
         class CustomVivadoProject(VivadoProject):
-            def pre_create(self, **kwargs):  # pylint: disable=no-self-use, unused-argument
+            def pre_create(self, **kwargs):  # pylint: disable=unused-argument
                 return False
 
         assert not self._create(CustomVivadoProject(name="apa", modules=[], part=""))
@@ -293,13 +287,13 @@ class TestVivadoProject(unittest.TestCase):
                 run_index=self.run_index,
                 generics=self.build_time_generics,
                 synth_only=self.synth_only,
+                from_impl=self.from_impl,
                 num_threads=self.num_threads,
             )
             module.create_regs_vhdl_package.assert_called_once()
 
     def test_default_pre_and_post_build_hooks_should_pass(self):
         class CustomVivadoProject(VivadoProject):
-
             pass
 
         build_result = self._build(CustomVivadoProject(name="apa", modules=[], part=""))
@@ -308,7 +302,7 @@ class TestVivadoProject(unittest.TestCase):
 
     def test_project_pre_build_hook_returning_false_should_fail_and_not_call_vivado_run(self):
         class CustomVivadoProject(VivadoProject):
-            def pre_build(self, **kwargs):  # pylint: disable=no-self-use, unused-argument
+            def pre_build(self, **kwargs):  # pylint: disable=unused-argument
                 return False
 
         build_result = self._build(CustomVivadoProject(name="apa", modules=[], part=""))
@@ -317,7 +311,7 @@ class TestVivadoProject(unittest.TestCase):
 
     def test_project_post_build_hook_returning_false_should_fail(self):
         class CustomVivadoProject(VivadoProject):
-            def post_build(self, **kwargs):  # pylint: disable=no-self-use, unused-argument
+            def post_build(self, **kwargs):  # pylint: disable=unused-argument
                 return False
 
         build_result = self._build(CustomVivadoProject(name="apa", modules=[], part=""))
@@ -339,6 +333,7 @@ class TestVivadoProject(unittest.TestCase):
             run_index=self.run_index,
             generics=copy_and_combine_dicts(dict(static_generic=2), self.build_time_generics),
             synth_only=self.synth_only,
+            from_impl=self.from_impl,
             num_threads=self.num_threads,
             other_parameter="hest",
             apa=123,
@@ -451,3 +446,97 @@ class TestVivadoProject(unittest.TestCase):
         assert self._build(project).success
 
         assert module.registers == "Some value"
+
+    def test_get_size_is_called_correctly(self):
+        project = VivadoProject(name="apa", modules=[], part="")
+
+        def _build_with_size(synth_only):
+            """
+            The project.build() call is very similar to _build() method in this class, but it mocks
+            the _get_size() method in a different way.
+            """
+            with patch(
+                "tsfpga.vivado.project.run_vivado_tcl", autospec=True
+            ) as self.mocked_run_vivado_tcl, patch(
+                "tsfpga.vivado.project.HierarchicalUtilizationParser.get_size", autospec=True
+            ) as mocked_get_size, patch(
+                "tsfpga.vivado.project.shutil.copy2", autospec=True
+            ) as _:
+                # Only the first return value will be used if we are in synth_only
+                mocked_get_size.side_effect = ["synth_size", "impl_size"]
+
+                build_result = project.build(
+                    project_path=self.project_path,
+                    output_path=self.output_path,
+                    run_index=self.run_index,
+                    synth_only=synth_only,
+                )
+
+                assert build_result.synthesis_size == "synth_size"
+
+                if synth_only:
+                    mocked_get_size.assert_called_once_with("synth_file")
+                    assert build_result.implementation_size is None
+                else:
+                    assert mocked_get_size.call_count == 2
+                    mocked_get_size.assert_any_call("synth_file")
+                    mocked_get_size.assert_any_call("impl_file")
+
+                    assert build_result.implementation_size == "impl_size"
+
+        create_file(self.project_path / "apa.xpr")
+
+        create_file(
+            self.project_path / "apa.runs" / "synth_3" / "hierarchical_utilization.rpt",
+            contents="synth_file",
+        )
+        create_file(
+            self.project_path / "apa.runs" / "impl_3" / "hierarchical_utilization.rpt",
+            contents="impl_file",
+        )
+
+        _build_with_size(synth_only=True)
+        _build_with_size(synth_only=False)
+
+    def test_netlist_build_should_set_logic_level_distribution(self):
+        def _build_with_logic_level_distribution(project):
+            """
+            The project.build() call is very similar to _build() method in this class, except it
+            also mocks the _get_logic_level_distribution() method.
+            """
+            with patch(
+                "tsfpga.vivado.project.run_vivado_tcl", autospec=True
+            ) as self.mocked_run_vivado_tcl, patch(
+                "tsfpga.vivado.project.VivadoProject._get_size", autospec=True
+            ) as _, patch(
+                "tsfpga.vivado.project.shutil.copy2", autospec=True
+            ) as _, patch(
+                "tsfpga.vivado.project.LogicLevelDistributionParser.get_table", autospec=True
+            ) as mocked_get_table:
+                mocked_get_table.return_value = "logic_table"
+
+                build_result = project.build(
+                    project_path=self.project_path,
+                    output_path=self.output_path,
+                    run_index=self.run_index,
+                )
+
+                if project.is_netlist_build:
+                    mocked_get_table.assert_called_once_with("logic_file")
+                    assert build_result.logic_level_distribution == "logic_table"
+                else:
+                    mocked_get_table.assert_not_called()
+                    assert build_result.logic_level_distribution is None
+                    assert build_result.maximum_logic_level is None
+
+        create_file(self.project_path / "apa.xpr")
+        create_file(
+            self.project_path / "apa.runs" / "synth_3" / "logical_level_distribution.rpt",
+            contents="logic_file",
+        )
+
+        project = VivadoNetlistProject(name="apa", modules=[], part="")
+        _build_with_logic_level_distribution(project=project)
+
+        project = VivadoProject(name="apa", modules=[], part="")
+        _build_with_logic_level_distribution(project=project)
